import { Component } from '@angular/core';
import { CommonModule } from '@angular/common';
import { Store, select } from '@ngrx/store';
import { Observable } from 'rxjs';
import { increment, decrement, reset } from '../counter.actions';
import { Counterdata } from '../counterdata';

@Component({
  selector: 'app-counter1',
  standalone: true,
  imports: [CommonModule],
  templateUrl: './counter1.component.html',
  styleUrls: ['./counter1.component.css'],
})
export class Counter1Component {
  // count$ on observable, joka sisältää numeron
  count$: Observable<number>;

  /*
   Konstruktorin argumenttina luodaan Store-luokasta store-olio, 
   joka säilyttää muistissa sovelluksen tilaa, jonka tyyppi on
   Counterdata.
  */
  constructor(private store: Store<Counterdata>) {
    /* this.count$ saa arvon, kun storesta valitaan
       Select-metodilla 'count'. Kyseessä on yksinkertaisin 
       mahdollinen selektori.
    */
    this.count$ = store.pipe(select('count'));
  }
  /* 
    increment-metodi suorittaa increment-actionin.
    Action välitetään reducerin kautta (dispatch) storeen, 
    jolloin storessa count lisääntyy yhdellä
  */
  increment() {
    this.store.dispatch(increment());
  }

  decrement() {
    this.store.dispatch(decrement());
  }

  reset() {
    this.store.dispatch(reset());
  }
}
